import * as cdk from '@aws-cdk/core';
/**
 * AWS Account input details.
 */
export interface AccountSpec {
    /**
     * The name of the AWS account.
     */
    readonly name: string;
    /**
     * The email associated to the AWS account.
     */
    readonly email?: string;
}
/**
 * Organizational Unit Input details.
 */
export interface OUSpec {
    /**
     * Name of the Organizational Unit.
     */
    readonly name: string;
    /**
     * Accounts' specification inside in this Organizational Unit.
     */
    readonly accounts: AccountSpec[];
    /**
     * Specification of sub Organizational Unit.
     */
    readonly nestedOU?: OUSpec[];
}
/**
 * (experimental) Properties for AWS SDLC Organizations Stack.
 *
 * @experimental
 */
export interface AwsOrganizationsStackProps extends cdk.StackProps {
    /**
     * (experimental) Email address of the Root account.
     *
     * @experimental
     */
    readonly email: string;
    /**
     * (experimental) Specification of the sub Organizational Unit.
     *
     * @experimental
     */
    readonly nestedOU: OUSpec[];
    /**
     * (experimental) Enable Email Verification Process.
     *
     * @experimental
     */
    readonly forceEmailVerification?: boolean;
}
/**
 * A Stack creating the Software Development Life Cycle (SDLC) Organization.
 */
export declare class AwsOrganizationsStack extends cdk.Stack {
    private readonly emailPrefix?;
    private readonly domain?;
    private createOrganizationTree;
    constructor(scope: cdk.Construct, id: string, props: AwsOrganizationsStackProps);
}
